#
# Script version 1.0
#
# Version history:
#  1.0  First version of this script
#
# This before-matching filter is used to use external SIP redirect servers 
# (All Call Query (ACQ) call flows.
#
# An ACQ call flow consists of, for each incoming call, calling a redirect
# server on a dedicated NAP. The redirect server then provides the routing
# number which is then used to route the call to the correct NAP.
#
# This is a example of the 300 Redirect contact header returned from the Routing server:
# Contact URI: sip:19738398871@192.104.111.65;dtg=40060;rtid=50009;jd=11;md=1973839
# Contact URI: sip:19738398871@192.104.111.65;dtg=40076;rtid=50009;jd=11;md=1973839
# Contact URI: sip:19738398871@192.104.111.65;dtg=40120;rtid=50009;jd=11;md=1973839
# ...
#
# In order to use this module, follow the steps below:
# 1- Add the "require 'redirect_routing'" statement at the top of the main script.
# 2- Add the "include RedirectQuery" statement in the main routing class.
# 3- Add the filter "  before_filter :method => :redirect_query" in the main routing class.
# 4- Create a NAP column with name "server_type". Use REDIRECT for Redirect Servers
# 5- Add the nap_group_weight_load_balancer.rb  script to the main script (with group and weight options in the NAP)
#
#

module RedirectQuery
  
  def init_redirect_query(params)
    params
  end
  
  def redirect_query(params)
    call = params[:call]
    nap_lists = params[:naps]
    routes = clone_routes params[:routes]
        
  # Added this to support request_uri 302 routing
    params[:call][:request_uri_forward_enabled] = 'true'

    
    log_trace 1, "params = " + params.inspect
    log_trace 1, "nap_lists = " + nap_lists.inspect
    log_trace 1, "routes = " + routes.inspect
    
    # Verify if this routing query is for an incoming call
    # To find this, we look at the contact index (it should be zero)
    contacts = params[:contacts]
    contact_index = contacts[:index].to_i
    
    log_trace 2, "contacts = " + contacts.inspect
    
    # If it is an incoming call, then contacts and need to add the redirect servers in the list
    if (contact_index == 0)
      log_trace 2, "Use Redirect Routing"
      newroutes = []

      # Replace current routes with a list of Redirect routes
      nap_lists.each do |nap_list,nap_info|
#        log_trace 1, "nap_list =" + nap_list.inspect
#        log_trace 1, "nap_info =" + nap_info.inspect
#        log_trace 1, "This_nap.server_type =" + nap_info[:server_type].inspect
        if nap_info[:server_type] == "REDIRECT"
          log_trace 1, "nap " + nap_info[:name].inspect + " is for Redirect Server"
          newroutes << { :name => nap_info[:name], :remapped_nap => nap_info[:name], :group => nap_info[:group], :weight => nap_info[:weight]}
        end
      end
      log_trace 1, "Redirect routes = " + newroutes.inspect
      #      Check if there is at least one valid Redirect server
      #      unless newroutes.nil?  # || newroutes == 0  # This line is not working...
        params[:routes] = newroutes
    end
    
    params
  end
end