#
# Script version 1.1
#
# Version history
#  1.1  (start of version history tracking)
#

require 'base_routing'
require 'redirect_routing'
require 'nap_group_weight_load_balancer'

# This script routes calls in the most simple fashion. The behavior is the same as routing without ruby scripts
# with the addition of nap availability.
#
# Routing is in the following order
#
#  Matching ttBaseRouting.route_matchtt
#    ttcall_field_name = calledtt - Match the called number of the call to a route.
#    ttcall_field_name = callingtt - Match the calling number of the call to a route.
#    ttcall_field_name = naptt - Match the nap of the call to a route.
#    ttmethod = match_nap_availabilitytt - Match the call to a route using BaseRouting.match_nap_availability.
#  Remapping ttBaseRouting.route_remaptt
#    ttcall_field_name = called, route_field_name = remapped_calledtt - Remap the called
#     number for the outgoing call.
#    ttcall_field_name = calling, route_field_name = remapped_callingtt - Remap the calling
#     number for the outgoing call.
#    ttcall_field_name = nap, route_field_name = remapped_naptt - Remap the nap for the outgoing call.
#     This means setting the destination nap for the route.
#


class SimpleRouting  BaseRouting
include RedirectQuery
include NapGroupAndWeightLoadBalancer
  
  before_filter method = redirect_query

  route_match call_field_name = called
  route_match call_field_name = calling
  route_match call_field_name = nap
  route_remap call_field_name = called, route_field_name = remapped_called
  route_remap call_field_name = calling, route_field_name = remapped_calling
  route_remap call_field_name = nap, route_field_name = remapped_nap
  
  
  # This is where the routes are being sorted according to destination NAP groups and weight
  after_filter method = filter_by_group_and_weight
  
end

@@routing = SimpleRouting.new

def init_routes( routes )
  @@routing.init routes
end

def route( call, nap_list )
  @@routing.route call, nap_list
end